==> aws-spa-3.1.2.tgz: package/lib/lambda.spec.js <==
"use strict";

var _lambda = require("./lambda");

var iam = _interopRequireWildcard(require("./iam"));

var _awsServices = require("./aws-services");

var _testHelper = require("./test-helper");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe("lambda", () => {
  jest.spyOn(iam, "getRoleARNForBasicLambdaExectution").mockResolvedValue("arn-value");
  describe("deploySimpleAuthLambda()", () => {
    const getFunction = jest.spyOn(_awsServices.lambda, "getFunction");
    const getFunctionConfiguration = jest.spyOn(_awsServices.lambda, "getFunctionConfiguration");
    const createFunction = jest.spyOn(_awsServices.lambda, "createFunction");
    const updateFunctionCode = jest.spyOn(_awsServices.lambda, "updateFunctionCode");
    const updateFunctionConfiguration = jest.spyOn(_awsServices.lambda, "updateFunctionConfiguration");
    beforeEach(() => {
      getFunction.mockReset();
      getFunctionConfiguration.mockReset();
      createFunction.mockReset();
      updateFunctionCode.mockReset();
    });
    it("should return the function ARN & version when function exists & credentials didn't change", async () => {
      getFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      getFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)({
        FunctionArn: "some-arn",
        Description: (0, _lambda.getDescription)("hello:hello"),
        Version: "1"
      }));
      expect((await (0, _lambda.deploySimpleAuthLambda)("hello.example.com", "hello:hello"))).toEqual("some-arn:1");
    });
    it("should create a lambda if function is not found", async () => {
      getFunction.mockReturnValueOnce((0, _testHelper.awsReject)(404));
      getFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)({
        FunctionArn: "some-arn",
        Description: (0, _lambda.getDescription)("hello:hello"),
        Version: "1"
      }));
      createFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _lambda.deploySimpleAuthLambda)("hello.example.com", "hello:hello");
      expect(createFunction).toHaveBeenCalledTimes(1);
      expect(createFunction.mock.calls[0][0].FunctionName).toEqual("aws-spa-basic-auth-hello-example-com");
    });
    it("should update code if credentials changed", async () => {
      getFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      getFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)({
        FunctionArn: "some-arn",
        Description: (0, _lambda.getDescription)("hello:hello"),
        Version: "1"
      }));
      createFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      updateFunctionCode.mockReturnValueOnce((0, _testHelper.awsResolve)({
        Version: "2"
      }));
      updateFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _lambda.deploySimpleAuthLambda)("hello.example.com", "new:credentials");
      expect(updateFunctionCode).toHaveBeenCalledTimes(1);
      expect(updateFunctionCode.mock.calls[0][0].FunctionName).toEqual("aws-spa-basic-auth-hello-example-com");
      expect(updateFunctionConfiguration).toHaveBeenCalledTimes(1);
      expect(updateFunctionConfiguration.mock.calls[0][0].FunctionName).toEqual("aws-spa-basic-auth-hello-example-com");
      expect(updateFunctionConfiguration.mock.calls[0][0].Description).toEqual((0, _lambda.getDescription)("new:credentials"));
    });
  });
});

==> aws-spa-4.0.0.tgz: package/lib/lambda.spec.js <==
"use strict";

var _lambda = require("./lambda");

var iam = _interopRequireWildcard(require("./iam"));

var _awsServices = require("./aws-services");

var _testHelper = require("./test-helper");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe("lambda", () => {
  jest.spyOn(iam, "getRoleARNForBasicLambdaExectution").mockResolvedValue("arn-value");
  describe("deploySimpleAuthLambda()", () => {
    const getFunction = jest.spyOn(_awsServices.lambda, "getFunction");
    const getFunctionConfiguration = jest.spyOn(_awsServices.lambda, "getFunctionConfiguration");
    const createFunction = jest.spyOn(_awsServices.lambda, "createFunction");
    const updateFunctionCode = jest.spyOn(_awsServices.lambda, "updateFunctionCode");
    const updateFunctionConfiguration = jest.spyOn(_awsServices.lambda, "updateFunctionConfiguration");
    beforeEach(() => {
      getFunction.mockReset();
      getFunctionConfiguration.mockReset();
      createFunction.mockReset();
      updateFunctionCode.mockReset();
    });
    it("should return the function ARN & version when function exists & credentials didn't change", async () => {
      getFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      getFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)({
        FunctionArn: "some-arn",
        Description: (0, _lambda.getDescription)("hello:hello"),
        Version: "1"
      }));
      expect(await (0, _lambda.deploySimpleAuthLambda)("hello.example.com", "hello:hello")).toEqual("some-arn:1");
    });
    it("should create a lambda if function is not found", async () => {
      getFunction.mockReturnValueOnce((0, _testHelper.awsReject)(404));
      getFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)({
        FunctionArn: "some-arn",
        Description: (0, _lambda.getDescription)("hello:hello"),
        Version: "1"
      }));
      createFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _lambda.deploySimpleAuthLambda)("hello.example.com", "hello:hello");
      expect(createFunction).toHaveBeenCalledTimes(1);
      expect(createFunction.mock.calls[0][0].FunctionName).toEqual("aws-spa-basic-auth-hello-example-com");
    });
    it("should update code if credentials changed", async () => {
      getFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      getFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)({
        FunctionArn: "some-arn",
        Description: (0, _lambda.getDescription)("hello:hello"),
        Version: "1"
      }));
      createFunction.mockReturnValueOnce((0, _testHelper.awsResolve)());
      updateFunctionCode.mockReturnValueOnce((0, _testHelper.awsResolve)({
        Version: "2"
      }));
      updateFunctionConfiguration.mockReturnValueOnce((0, _testHelper.awsResolve)());
      await (0, _lambda.deploySimpleAuthLambda)("hello.example.com", "new:credentials");
      expect(updateFunctionCode).toHaveBeenCalledTimes(1);
      expect(updateFunctionCode.mock.calls[0][0].FunctionName).toEqual("aws-spa-basic-auth-hello-example-com");
      expect(updateFunctionConfiguration).toHaveBeenCalledTimes(1);
      expect(updateFunctionConfiguration.mock.calls[0][0].FunctionName).toEqual("aws-spa-basic-auth-hello-example-com");
      expect(updateFunctionConfiguration.mock.calls[0][0].Description).toEqual((0, _lambda.getDescription)("new:credentials"));
    });
  });
});
